SystemOrganization addCategory: #'OmniBaseJ-Core'!

TestCase subclass: #OmniBaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniBaseJ-Core'!

OmniBaseTest class
	instanceVariableNames: 'testDirPath'!

!OmniBaseTest class methodsFor: 'accessing' stamp: 'mu 8/29/2005 08:16'!
createDb
	| db |
	[db := OmniBase createOn: self testDirPath]
		ensure: [db close]! !

!OmniBaseTest class methodsFor: 'defaults' stamp: 'mu 8/29/2005 08:16'!
defaultDbSubDirName
	^'omniBaseTestDb' copy! !

!OmniBaseTest class methodsFor: 'defaults' stamp: 'mu 8/29/2005 08:16'!
defaultDirectory
	| subDirName |
	subDirName := self defaultDbSubDirName.
	(FileDirectory default directoryExists: subDirName)
		ifFalse: [FileDirectory default createDirectory: subDirName].
	^ FileDirectory default directoryNamed: subDirName! !

!OmniBaseTest class methodsFor: 'accessing' stamp: 'mu 8/29/2005 08:16'!
deleteDb
	"self deleteDb"
	OmniBase closeAll.
	self defaultDirectory recursiveDelete! !

!OmniBaseTest class methodsFor: 'class initialization' stamp: 'mu 8/29/2005 08:16'!
initialize
	"OmniBaseJTest initialize"
	testDirPath _ nil.
	Smalltalk addToShutDownList: self! !

!OmniBaseTest class methodsFor: 'class initialization' stamp: 'mu 8/29/2005 08:16'!
obsolete
	Smalltalk removeFromShutDownList: self! !

!OmniBaseTest class methodsFor: 'accessing' stamp: 'mu 8/29/2005 08:16'!
openedDb
	"self openedDb"
	| retry db |
	retry := 0.
	[db := OmniBase openOn: self testDirPath]
		on: ODBError
		do: [:ex | 
			retry _ retry + 1.
			retry > 1
				ifTrue: [ex pass].
			self createDb.
			ex retry].
	^ db! !

!OmniBaseTest class methodsFor: 'shutting down' stamp: 'mu 8/29/2005 08:16'!
shutDown
	self deleteDb! !

!OmniBaseTest class methodsFor: 'defaults' stamp: 'mu 8/29/2005 08:16'!
testDirPath
	testDirPath ifNil: [testDirPath _ self defaultDirectory fullName].
	^testDirPath! !

!OmniBaseTest methodsFor: 'actions' stamp: 'mu 8/29/2005 08:16'!
doWhileDbOpening: aBlock 
	| db |
	^[db := self openedDb.
	aBlock value: db]
		ensure: [db close]! !

!OmniBaseTest methodsFor: 'accessing' stamp: 'mu 8/29/2005 08:16'!
openedDb
	^self class openedDb
	! !

!OmniBaseTest methodsFor: 'Testing' stamp: 'mu 8/29/2005 08:16'!
testStoreLoadByteArrayKey
	"self debug: #testStoreLoadByteArrayKey"
	self
		doWhileDbOpening: [:db | 
			| key stored | 
			[key := 'bytes' asByteArray.
			OmniBase root at: key put: #test]
				evaluateAndCommitIn: db newTransaction.
			stored := db newTransaction root at: key.
			self
				should: [stored = #test]]! !

!ODBBTreeIterator methodsFor: '*omnibaseJ-override-public' stamp: 'mu 9/12/2006 19:32'!
at: aString ifAbsent: aBlock 
	| key association str |
	key := ByteArray new: keyLength.
	str _ aString isWideString ifTrue: [aString asByteArray] ifFalse: [aString].
	key replaceFrom: 1 to: (str size min: keyLength) with: str startingAt: 1.
	association := self goToAndGetCurrentAt: key.
	self clearSearchCache.
	association isNil ifTrue: [^aBlock value].
	^association value odbLongAt: 1! !

!ODBBTreeIterator methodsFor: '*omnibaseJ-override-public' stamp: 'mu 9/12/2006 19:35'!
at: aString put: anInteger 
	| key value str |
	key := ByteArray new: keyLength.
	str _ aString isWideString ifTrue: [aString asByteArray] ifFalse: [aString].
	key 
		replaceFrom: 1
		to: (str size min: keyLength)
		with: str
		startingAt: 1.
	value := ByteArray new: 4.
	value odbLongAt: 1 put: anInteger.
	self
		goTo: key put: value;
		clearSearchCache.
	^anInteger! !

!ODBStream methodsFor: '*omnibaseJ' stamp: 'mu 9/13/2006 15:16'!
putWideString: aString

	| bytes |
	bytes _ aString asUnicodeByteArray.
	self putPositiveInteger: bytes size.
	self putByte: 0. "Mark for WideString"
	aString basicSize > 0 ifTrue: [ self putBytesFrom: bytes len: bytes size ]! !

!ODBClassDescription methodsFor: '*omnibaseJ-override' stamp: 'mu 9/13/2006 16:06'!
loadFromStream: aStream

	name := aStream getString.
	bytes := aStream getBoolean.
	variable := aStream getBoolean.
	instSize := aStream getPositiveInteger.
	instVarNames := Array new: instSize.
	1 to: instSize do: [:i | | str |
			str := aStream getString.
			str first asciiValue = 0 
				ifTrue: [str _ String fromUnicodeByteArray: (str copyFrom: 3 to: str size)].
			instVarNames at: i put: str].
	self updateVariableOrder.! !

!ODBClassDescription methodsFor: '*omnibaseJ-override' stamp: 'mu 9/13/2006 15:16'!
saveOnStream: aStream 
	aStream
		putString: name;
		putBoolean: bytes;
		putBoolean: variable;
		putPositiveInteger: instSize.

	instVarNames do: [:n | n isWideString ifTrue: [aStream putWideString: n] ifFalse: [aStream putString: n]]! !

!Object class methodsFor: '*omnibaseJ' stamp: 'mu 9/13/2006 11:58'!
odbLoadVariables: deserializer classInfo: classInfo

	| stream order iSize object basicSize varArray |
	stream := deserializer stream.
	classInfo isVariable
		ifTrue: [ object := self basicNew: (basicSize := stream getPositiveInteger) ]
		ifFalse: [
			basicSize := 0.
			object := self basicNew.
		].
	deserializer register: object.
	classInfo isBytes ifTrue: [
		self isWords 
			ifTrue: [1 to: basicSize do: [:i | object basicAt: i put: stream getInteger]]
			ifFalse: [stream getBytesFor: object len: basicSize].
		^object
	].

	varArray := Array new: (iSize := classInfo realInstSize) + 1.
	order := classInfo variableOrder.
	1 to: classInfo instSize do: [:i | varArray at: (order at: i) put: deserializer odbNextObject ].
	1 to: iSize do: [:i | object instVarAt: i put: (varArray at: i) ].
	iSize + 1 to: iSize + basicSize do: [:i | object instVarAt: i put: deserializer odbNextObject ].
	^object odbDeserialized: deserializer! !

Object subclass: #OmniBasePatchInstall
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniBaseJ-Core'!

!OmniBasePatchInstall class methodsFor: 'class initialization' stamp: 'mu 3/15/2006 10:50'!
initialize
	ODBDeserializer init! !

Object subclass: #OmniBasePrerequisitesInstall
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OmniBaseJ-Core'!

!OmniBasePrerequisitesInstall class methodsFor: 'class initialization' stamp: 'mu 3/25/2006 21:24'!
initialize
	"OmniBasePrerequisitesInstall initialize"
	Smalltalk addToStartUpList: self! !

!OmniBasePrerequisitesInstall class methodsFor: 'private' stamp: 'mu 3/25/2006 21:18'!
installBySM: idString version: versionString 
	| package release |
	package := SMSqueakMap default packageWithId: idString.
	release := package releaseWithAutomaticVersionString: versionString.
	(package isInstalled not
			or: [release newerThan: package installedRelease])
		ifTrue: [SMSqueakMap default installPackageRelease: release.
			Smalltalk
				at: #PackageOrganizer
				ifPresent: [:po | po default registerPackageNamed: release package name].
			Transcript cr; show: '##PreInstalled: ' , release printName; cr]! !

!OmniBasePrerequisitesInstall class methodsFor: 'installing' stamp: 'mu 4/14/2006 02:49'!
installOSProcess
	self shouldInstallOSProcess ifFalse: [^ self].
	{{'812c9d14-5236-4cad-82ea-cc3e3837e30d'. '7'.   "OSProcess"}}
		do: [:each | 
			self installBySM: each first version: each last]! !

!OmniBasePrerequisitesInstall class methodsFor: 'class initialization' stamp: 'mu 3/25/2006 20:47'!
obsolete
	Smalltalk removeFromStartUpList: self! !

!OmniBasePrerequisitesInstall class methodsFor: 'accessing' stamp: 'mu 3/25/2006 21:43'!
osVersion
	"OmniBasePrerequisitesInstall osVersion"
	^SmalltalkImage current osVersion asInteger ifNil: [0]! !

!OmniBasePrerequisitesInstall class methodsFor: 'accessing' stamp: 'mu 3/25/2006 21:45'!
platformName
	^ SmalltalkImage current platformName! !

!OmniBasePrerequisitesInstall class methodsFor: 'installing' stamp: 'mu 4/14/2006 02:49'!
shouldInstallOSProcess
	"OmniBasePrerequisitesInstall shouldInstallOSProcess"
	| platform |
	(Smalltalk hasClassNamed: #OSProcess) ifTrue: [^false].
	platform := self platformName.
	platform = 'Win32' ifTrue: [^ false].
	platform = 'unix' ifTrue: [^ true].
	^(platform = 'Mac OS') and: [self osVersion >= 1000]! !

!OmniBasePrerequisitesInstall class methodsFor: 'start up/shut down' stamp: 'mu 3/25/2006 21:22'!
startUp
	self installOSProcess! !

!String class methodsFor: '*omnibaseJ-instance creation' stamp: 'mu 9/13/2006 16:05'!
fromUnicodeByteArray: byteArray 
	| arr str warr |
	arr := byteArray.
	str := arr readStream.
	warr := WordArray new: arr size // 2.
	1
		to: warr size
		do: [:idx | warr at: idx put: str nextWord].
	^ self fromUnicodeWordArray: warr! !

!String class methodsFor: '*omnibaseJ-instance creation' stamp: 'mu 9/13/2006 15:24'!
fromUnicodeWordArray: wordArray
	| inst |
	inst _ self new: wordArray size.
	1 to: wordArray size do: [:i | inst at: i put: (Unicode value: (wordArray at: i))].
	^inst! !

!String methodsFor: '*omnibaseJ' stamp: 'mu 9/13/2006 13:44'!
asUnicodeByteArray
	| warr str |
	warr _ self asUnicodeWordArray.
	str _ WriteStream on: (ByteArray new: warr byteSize).
	warr do: [:each | str nextWordPut: each].
	^str contents  ! !

!String methodsFor: '*omnibaseJ' stamp: 'mu 9/13/2006 13:00'!
asUnicodeWordArray
	| arr |
	arr := WordArray new: self size.
	1
		to: arr size
		do: [:idx | arr at: idx put: (self at: idx) asUnicode].
	^ arr! !

!WideString class methodsFor: '*omnibaseJ' stamp: 'mu 8/3/2005 19:47'!
odbDeserialize: deserializer 
	| str len stream |
	str := self new: (len := (stream := deserializer stream) getPositiveInteger).
	1 to: len do: [:i | str at: i put: (Unicode value: stream getWord)].
	^deserializer register: str! !

!WideString methodsFor: '*omnibaseJ' stamp: 'mu 9/13/2006 13:02'!
odbBasicSerialize: serializer 
	| len stream |
	len := self size.
	(stream := serializer stream)
		putByte: 36;
		putPositiveInteger: len.
	1 to: len do: [:i | stream putWord: (self at: i) asUnicode]! !

!ODBDeserializer class methodsFor: '*omnibaseJ-private-override' stamp: 'mu 8/3/2005 19:26'!
init
	"ODBDeserializer init"
	classArray := Array new: 255.
	classArray
		at: 2 put: ODBNewObjectNewClass;
		at: 3 put: ODBNewObject;
		at: 4 put: ODBExistingObject;
		at: 5 put: ODBExternalReference;
		at: 6 put: ODBClassManagerForSerialization;
		at: 15 put: true;
		at: 16 put: false;
		at: 17 put: Message;
		at: 20 put: MessageSend;
		at: 19 put: Smalltalk;
		at: 22 put: Processor;
		at: 11 put: ODBLargePositiveInteger;
		at: 12 put: ODBLargeNegativeInteger;
		at: 13 put: Character;
		at: 29 put: ODBDoubleByteCharacter;
		at: 14 put: UndefinedObject;
		at: 10 put: nil;
		at: 18 put: Symbol;
		at: 26 put: Class;
		at: 31 put: Association;
		at: 32 put: Date;
		at: 33 put: Time;
		at: 34 put: String;
		at: 35 put: Array;
		at: 36 put: WideString; "Squeak"
		at: 37 put: Dictionary;
		at: 38 put: IdentityDictionary;
		at: 39 put: Fraction;
		at: 40 put: Float;
		at: 41 put: (ODBCopyValue value: 0.0);
		at: 42 put: (ODBCopyValue value: 1.0);
		at: 43 put: ODBFloatAsInteger;
		at: 44 put: ODBFloatAs100Integer;
		at: 45 put: ODB8ByteFloat;
		"should be ScaledDecimal but Squeak has not support for ScaledDecimal class, e.g. 1.0s does not work"
		at: 46 put: Float;
		at: 50 put: 0;
		at: 51 put: 1;
		at: 52 put: 2;
		at: 53 put: 3;
		at: 54 put: 4;
		at: 55 put: 5;
		at: 56 put: 6;
		at: 57 put: 7;
		at: 58 put: 8;
		at: 59 put: 9;
		at: 60 put: 10;
		at: 61 put: 11;
		at: 62 put: 12;
		at: 63 put: 13;
		at: 64 put: 14;
		at: 65 put: 15;
		at: 66 put: 16;
		at: 67 put: -3;
		at: 68 put: -2;
		at: 69 put: -1;
		at: 70 put: ODBEmptyString;
		at: 71 put: ODB1CharacterString;
		at: 72 put: (ODBnCharacterString length: 2);
		at: 73 put: (ODBnCharacterString length: 3);
		at: 74 put: (ODBnCharacterString length: 4);
		at: 75 put: (ODBnCharacterString length: 5);
		at: 76 put: (ODBnCharacterString length: 6);
		at: 77 put: (ODBnCharacterString length: 7);
		at: 78 put: (ODBnCharacterString length: 8);
		at: 79 put: (ODBnCharacterString length: 9);
		at: 80 put: ByteArray;
		at: 81 put: OrderedCollection;
		at: 82 put: ODBIdentityDictionary;
		at: 83 put: ODBPersistentDictionary;
		at: 84 put: ODBTransaction;
		yourself.! !

!ODBLocalTransaction methodsFor: '*omnibaseJ-public-override' stamp: 'MU 2/22/2006 14:17'!
makePersistent: anObject in: aContainerOrContainerName 
	"Store anObject into specified container if it is not stored yet, else do nothing.
	Answer anObject."

	| container |
	anObject odbObjectID isNil ifFalse: [^anObject].
	self getTransactionObject: anObject
		ifAbsent: 
			[aContainerOrContainerName isString 
				ifTrue: 
					[container := dbConnection objectManager containerNamed: aContainerOrContainerName
								ifAbsent: [OmniBase signalError: 'Container does not exist']]
				ifFalse: [container := aContainerOrContainerName].
			self storeNewObject: anObject inContainer: container].
	^anObject! !
OmniBaseTest initialize!
OmniBasePatchInstall initialize!
OmniBasePrerequisitesInstall initialize!
